@@ -33,11 +33,6 @@ def main():
     main_parser.parse(args[1:])
     logging.info(f"Parser \"{args[0]}\" finished")
 
-    logging.info("removing log files")
-    os.system("rm *.log")
-
-    os.system("cf gen")
-
 
 if __name__ == "__main__":
     main()
